.. _Embedders:

*********
Embedders
*********

.. toctree::
   :maxdepth: 2

Embedders are a special case of Taggers which convert data into vector format.

The main reason to use an embedder is to provide data to an :ref:`Embedding Search Index for search <Embedding Search Index>`.
